# fastax
## Overview
fastax is a Deep Learning Library built on top of Google's [JAX](https://github.com/google/jax/tree/master/jax) that tries to
facilitate doing research by providing a combination of JAX's versatility with implementations of
the most used neural networks layers and utilities.

## More concrete information and naming
fastax is both a combination of fastai and JAX and fastai and stax:
* It is built on top of JAX and most of its original code comes from its Neural Network mini-library stax
* One of the long term goals of this library is implementing Jeremy Howard's fastai course ["Deep Learning From the Foundations"](https://course.fast.ai/part2)

For more information visit https://github.com/joaogui1/fastax
